pub fn get_easing(etype: Easing) -> EasingFunctionExpand description
Returns the easing function with the given [name].
[name] can be an EasingFunction or a String specifying the name of one of the easing functions defined above.
pub fn get_easing(etype: Easing) -> EasingFunctionReturns the easing function with the given [name].
[name] can be an EasingFunction or a String specifying the name of one of the easing functions defined above.